@@ -37,6 +37,31 @@ class UserUpdate(task_manager.Task):
         return client.keystone_client.users.update(**self.args)
 
 
+class UserGet(task_manager.Task):
+    def main(self, client):
+        return client.keystone_client.users.get(**self.args)
+
+
+class ProjectList(task_manager.Task):
+    def main(self, client):
+        return client._project_manager.list()
+
+
+class ProjectCreate(task_manager.Task):
+    def main(self, client):
+        return client._project_manager.create(**self.args)
+
+
+class ProjectDelete(task_manager.Task):
+    def main(self, client):
+        return client._project_manager.delete(**self.args)
+
+
+class ProjectUpdate(task_manager.Task):
+    def main(self, client):
+        return client._project_manager.update(**self.args)
+
+
 class FlavorList(task_manager.Task):
     def main(self, client):
         return client.nova_client.flavors.list(**self.args)
@@ -76,6 +101,11 @@ class ServerList(task_manager.Task):
         return client.nova_client.servers.list(**self.args)
 
 
+class ServerListSecurityGroups(task_manager.Task):
+    def main(self, client):
+        return client.nova_client.servers.list_security_group(**self.args)
+
+
 class ServerGet(task_manager.Task):
     def main(self, client):
         return client.nova_client.servers.get(**self.args)
@@ -361,6 +391,11 @@ class ContainerUpdate(task_manager.Task):
         client.swift_client.post_container(**self.args)
 
 
+class ContainerList(task_manager.Task):
+    def main(self, client):
+        return client.swift_client.list(**self.args)
+
+
 class ObjectCapabilities(task_manager.Task):
     def main(self, client):
         return client.swift_client.get_capabilities(**self.args)
@@ -381,6 +416,11 @@ class ObjectUpdate(task_manager.Task):
         client.swift_client.post_object(**self.args)
 
 
+class ObjectList(task_manager.Task):
+    def main(self, client):
+        return client.swift_client.list(**self.args)
+
+
 class ObjectMetadata(task_manager.Task):
     def main(self, client):
         return client.swift_client.head_object(**self.args)
@@ -536,42 +576,37 @@ class EndpointDelete(task_manager.Task):
         return client.keystone_client.endpoints.delete(**self.args)
 
 
-# IdentityDomain and not Domain because Domain is a DNS concept
-class IdentityDomainCreate(task_manager.Task):
+class DomainCreate(task_manager.Task):
     def main(self, client):
         return client.keystone_client.domains.create(**self.args)
 
 
-# IdentityDomain and not Domain because Domain is a DNS concept
-class IdentityDomainList(task_manager.Task):
+class DomainList(task_manager.Task):
     def main(self, client):
         return client.keystone_client.domains.list()
 
 
-# IdentityDomain and not Domain because Domain is a DNS concept
-class IdentityDomainGet(task_manager.Task):
+class DomainGet(task_manager.Task):
     def main(self, client):
         return client.keystone_client.domains.get(**self.args)
 
 
-# IdentityDomain and not Domain because Domain is a DNS concept
-class IdentityDomainUpdate(task_manager.Task):
+class DomainUpdate(task_manager.Task):
     def main(self, client):
         return client.keystone_client.domains.update(**self.args)
 
 
-# IdentityDomain and not Domain because Domain is a DNS concept
-class IdentityDomainDelete(task_manager.Task):
+class DomainDelete(task_manager.Task):
     def main(self, client):
         return client.keystone_client.domains.delete(**self.args)
 
 
-class DomainList(task_manager.Task):
+class ZoneList(task_manager.Task):
     def main(self, client):
         return client.designate_client.domains.list()
 
 
-class DomainGet(task_manager.Task):
+class ZoneGet(task_manager.Task):
     def main(self, client):
         return client.designate_client.domains.get(**self.args)
 
@@ -599,3 +634,18 @@ class RoleCreate(task_manager.Task):
 class RoleDelete(task_manager.Task):
     def main(self, client):
         return client.keystone_client.roles.delete(**self.args)
+
+
+class StackList(task_manager.Task):
+    def main(self, client):
+        return client.heat_client.stacks.list()
+
+
+class StackCreate(task_manager.Task):
+    def main(self, client):
+        return client.heat_client.stacks.create(**self.args)
+
+
+class StackDelete(task_manager.Task):
+    def main(self, client):
+        return client.heat_client.stacks.delete(**self.args)
