@@ -12,12 +12,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from decorator import decorator
+import inspect
 import time
 
 import netifaces
 
+from shade import _log
 from shade import exc
 
+log = _log.setup_logging(__name__)
+
 
 def _iterate_timeout(timeout, message, wait=2):
     """Iterate and raise an exception on timeout.
@@ -33,17 +38,19 @@ def _iterate_timeout(timeout, message, wait=2):
     while (timeout is None) or (time.time() < start + timeout):
         count += 1
         yield count
+        log.debug('Waiting {wait} seconds'.format(wait=wait))
         time.sleep(wait)
     raise exc.OpenStackCloudTimeout(message)
 
 
-def _filter_list(data, name_or_id, filters):
+def _filter_list(data, name_or_id, filters, name_key='name'):
     """Filter a list by name/ID and arbitrary meta data.
 
     :param list data:
         The list of dictionary data to filter. It is expected that
-        each dictionary contains an 'id', 'name' (or 'display_name')
-        key if a value for name_or_id is given.
+        each dictionary contains an 'id' and 'name'
+        key if a value for name_or_id is given. The 'name' key can be
+        overridden with the name_key parameter.
     :param string name_or_id:
         The name or ID of the entity being filtered.
     :param dict filters:
@@ -56,15 +63,16 @@ def _filter_list(data, name_or_id, filters):
                   'gender': 'Female'
               }
             }
+    :param string name_key:
+        The name of the name key. Cinder wants display_name. Heat wants
+        stack_name. Defaults to 'name'
     """
     if name_or_id:
         identifier_matches = []
         for e in data:
             e_id = str(e.get('id', None))
-            e_name = e.get('name', None)
-            # cinder likes to be different and use display_name
-            e_display_name = e.get('display_name', None)
-            if str(name_or_id) in (e_id, e_name, e_display_name):
+            e_name = e.get(name_key, None)
+            if str(name_or_id) in (e_id, e_name):
                 identifier_matches.append(e)
         data = identifier_matches
 
@@ -270,3 +278,44 @@ def localhost_supports_ipv6():
     """
 
     return netifaces.AF_INET6 in netifaces.gateways()['default']
+
+
+def normalize_users(users):
+    return [
+        dict(
+            id=user.get('id'),
+            email=user.get('email'),
+            name=user.get('name'),
+            username=user.get('username'),
+            default_project_id=user.get('default_project_id',
+                                        user.get('tenantId')),
+            domain_id=user.get('domain_id'),
+            enabled=user.get('enabled'),
+        ) for user in users
+    ]
+
+
+def valid_kwargs(*valid_args):
+    # This decorator checks if argument passed as **kwargs to a function are
+    # present in valid_args.
+    #
+    # Typically, valid_kwargs is used when we want to distinguish between
+    # None and omitted arguments and we still want to validate the argument
+    # list.
+    #
+    # Example usage:
+    #
+    # @valid_kwargs('opt_arg1', 'opt_arg2')
+    # def my_func(self, mandatory_arg1, mandatory_arg2, **kwargs):
+    #   ...
+    #
+    @decorator
+    def func_wrapper(func, *args, **kwargs):
+        argspec = inspect.getargspec(func)
+        for k in kwargs:
+            if k not in argspec.args[1:] and k not in valid_args:
+                raise TypeError(
+                    "{f}() got an unexpected keyword argument "
+                    "'{arg}'".format(f=inspect.stack()[1][3], arg=k))
+        return func(*args, **kwargs)
+    return func_wrapper
