@@ -13,7 +13,7 @@
 # limitations under the License.
 
 
-import bunch
+import munch
 import ipaddress
 import six
 
@@ -264,6 +264,12 @@ def expand_server_vars(cloud, server):
     return server_vars
 
 
+def expand_server_security_groups(cloud, server):
+    groups = cloud.list_server_security_groups(server)
+
+    server['security_groups'] = groups
+
+
 def get_hostvars_from_server(cloud, server, mounts=None):
     """Expand additional server information useful for ansible inventory."""
     server_vars = expand_server_vars(cloud, server)
@@ -274,6 +280,8 @@ def get_hostvars_from_server(cloud, server, mounts=None):
         server_vars['flavor']['name'] = flavor_name
     server_vars['flavor'].pop('links', None)
 
+    expand_server_security_groups(cloud, server)
+
     # OpenStack can return image as a string when you've booted from volume
     if str(server['image']) == server['image']:
         image_id = server['image']
@@ -315,10 +323,10 @@ def obj_to_dict(obj):
     that we can just have a plain dict of all of the values that exist in the
     nova metadata for a server.
     """
-    # If we obj_to_dict twice, don't fail, just return the bunch
-    if type(obj) == bunch.Bunch:
+    # If we obj_to_dict twice, don't fail, just return the munch
+    if type(obj) == munch.Munch:
         return obj
-    instance = bunch.Bunch()
+    instance = munch.Munch()
     for key in dir(obj):
         value = getattr(obj, key)
         if isinstance(value, NON_CALLABLES) and not key.startswith('_'):
@@ -343,7 +351,7 @@ def warlock_to_dict(obj):
     # glanceclient v2 uses warlock to construct its objects. Warlock does
     # deep black magic to attribute look up to support validation things that
     # means we cannot use normal obj_to_dict
-    obj_dict = bunch.Bunch()
+    obj_dict = munch.Munch()
     for (key, value) in obj.items():
         if isinstance(value, NON_CALLABLES) and not key.startswith('_'):
             obj_dict[key] = value
