@@ -19,7 +19,6 @@ test_compute
 Functional tests for `shade` compute methods.
 """
 
-from novaclient.v2.servers import Server
 from shade import openstack_cloud
 from shade.tests import base
 from shade.tests.functional.util import pick_flavor, pick_image
@@ -28,8 +27,7 @@ from shade.tests.functional.util import pick_flavor, pick_image
 class TestCompute(base.TestCase):
     def setUp(self):
         super(TestCompute, self).setUp()
-        # Shell should have OS-* envvars from openrc, typically loaded by job
-        self.cloud = openstack_cloud()
+        self.cloud = openstack_cloud(cloud='devstack')
         self.nova = self.cloud.nova_client
         self.flavor = pick_flavor(self.nova.flavors.list())
         if self.flavor is None:
@@ -47,15 +45,15 @@ class TestCompute(base.TestCase):
         self.addCleanup(self._cleanup_servers)
         server = self.cloud.create_server(name='test_create_server',
                                           image=self.image, flavor=self.flavor)
-        self.assertIsInstance(server, Server)
-        self.assertEquals(server.name, 'test_create_server')
-        self.assertEquals(server.image['id'], self.image.id)
-        self.assertEquals(server.flavor['id'], self.flavor.id)
+        self.assertEquals(server['name'], 'test_create_server')
+        self.assertEquals(server['image']['id'], self.image.id)
+        self.assertEquals(server['flavor']['id'], self.flavor.id)
 
     def test_delete_server(self):
         self.cloud.create_server(name='test_delete_server',
                                  image=self.image, flavor=self.flavor)
-        server_deleted = self.cloud.delete_server('test_delete_server')
+        server_deleted = self.cloud.delete_server('test_delete_server',
+                                                  wait=True)
         self.assertIsNone(server_deleted)
 
     def test_get_image_id(self):
