@@ -15,7 +15,7 @@
 import mock
 import os_client_config as occ
 
-import bunch
+import munch
 
 import shade
 from shade import exc
@@ -29,9 +29,9 @@ class TestDomainParams(base.TestCase):
         self.cloud = shade.openstack_cloud(validate=False)
 
     @mock.patch.object(occ.cloud_config.CloudConfig, 'get_api_version')
-    @mock.patch.object(shade.OpenStackCloud, '_get_project')
+    @mock.patch.object(shade.OpenStackCloud, 'get_project')
     def test_identity_params_v3(self, mock_get_project, mock_api_version):
-        mock_get_project.return_value = bunch.Bunch(id=1234)
+        mock_get_project.return_value = munch.Munch(id=1234)
         mock_api_version.return_value = '3'
 
         ret = self.cloud._get_identity_params(domain_id='5678', project='bar')
@@ -41,10 +41,10 @@ class TestDomainParams(base.TestCase):
         self.assertEqual(ret['domain'], '5678')
 
     @mock.patch.object(occ.cloud_config.CloudConfig, 'get_api_version')
-    @mock.patch.object(shade.OpenStackCloud, '_get_project')
+    @mock.patch.object(shade.OpenStackCloud, 'get_project')
     def test_identity_params_v3_no_domain(
             self, mock_get_project, mock_api_version):
-        mock_get_project.return_value = bunch.Bunch(id=1234)
+        mock_get_project.return_value = munch.Munch(id=1234)
         mock_api_version.return_value = '3'
 
         self.assertRaises(
@@ -53,9 +53,9 @@ class TestDomainParams(base.TestCase):
             domain_id=None, project='bar')
 
     @mock.patch.object(occ.cloud_config.CloudConfig, 'get_api_version')
-    @mock.patch.object(shade.OpenStackCloud, '_get_project')
+    @mock.patch.object(shade.OpenStackCloud, 'get_project')
     def test_identity_params_v2(self, mock_get_project, mock_api_version):
-        mock_get_project.return_value = bunch.Bunch(id=1234)
+        mock_get_project.return_value = munch.Munch(id=1234)
         mock_api_version.return_value = '2'
 
         ret = self.cloud._get_identity_params(domain_id='foo', project='bar')
@@ -63,9 +63,9 @@ class TestDomainParams(base.TestCase):
         self.assertEqual(ret['tenant_id'], 1234)
         self.assertNotIn('domain', ret)
 
-    @mock.patch.object(shade.OpenStackCloud, '_get_project')
+    @mock.patch.object(shade.OpenStackCloud, 'get_project')
     def test_identity_params_v2_no_domain(self, mock_get_project):
-        mock_get_project.return_value = bunch.Bunch(id=1234)
+        mock_get_project.return_value = munch.Munch(id=1234)
 
         self.cloud.api_versions = dict(identity='2')
 
