@@ -30,13 +30,13 @@ from shade.tests.unit import base
 class CloudServices(base.TestCase):
     mock_services = [
         {'id': 'id1', 'name': 'service1', 'type': 'type1',
-         'description': 'desc1'},
+         'service_type': 'type1', 'description': 'desc1'},
         {'id': 'id2', 'name': 'service2', 'type': 'type2',
-         'description': 'desc2'},
+         'service_type': 'type2', 'description': 'desc2'},
         {'id': 'id3', 'name': 'service3', 'type': 'type2',
-         'description': 'desc3'},
+         'service_type': 'type2', 'description': 'desc3'},
         {'id': 'id4', 'name': 'service4', 'type': 'type3',
-         'description': 'desc4'}
+         'service_type': 'type3', 'description': 'desc4'}
     ]
 
     def setUp(self):
@@ -51,11 +51,12 @@ class CloudServices(base.TestCase):
     def test_create_service(self, mock_keystone_client):
         kwargs = {
             'name': 'a service',
-            'service_type': 'network',
+            'type': 'network',
             'description': 'This is a test service'
         }
 
         self.client.create_service(**kwargs)
+        kwargs['service_type'] = kwargs.pop('type')
         mock_keystone_client.services.create.assert_called_with(**kwargs)
 
     @patch.object(OperatorCloud, 'keystone_client')
