@@ -13,8 +13,10 @@
 # under the License.
 
 import mock
+import munch
 
 import glanceclient
+from heatclient import client as heat_client
 from keystoneclient.v2_0 import client as k2_client
 from keystoneclient.v3 import client as k3_client
 from neutronclient.common import exceptions as n_exc
@@ -111,6 +113,20 @@ class TestShade(base.TestCase):
             service_type='image', session=mock.ANY,
         )
 
+    @mock.patch.object(shade.OpenStackCloud, 'keystone_session')
+    @mock.patch.object(heat_client, 'Client')
+    def test_heat_args(self, mock_client, mock_keystone_session):
+        mock_keystone_session.return_value = None
+        self.cloud.heat_client
+        mock_client.assert_called_with(
+            endpoint_type='public',
+            region_name='',
+            service_name=None,
+            service_type='orchestration',
+            session=mock.ANY,
+            version='1'
+        )
+
     @mock.patch.object(shade.OpenStackCloud, 'search_subnets')
     def test_get_subnet(self, mock_search):
         subnet = dict(id='123', name='mickey')
@@ -368,18 +384,52 @@ class TestShade(base.TestCase):
             self.assertRaises(exc.OpenStackCloudException,
                               self.cloud.list_networks)
 
-    @mock.patch.object(shade.OpenStackCloud, 'list_domains')
-    def test_get_domain(self, mock_search):
-        domain1 = dict(id='123', name='mickey')
-        mock_search.return_value = [domain1]
-        r = self.cloud.get_domain('mickey')
+    @mock.patch.object(shade.OpenStackCloud, 'list_zones')
+    def test_get_zone(self, mock_search):
+        zone1 = dict(id='123', name='mickey')
+        mock_search.return_value = [zone1]
+        r = self.cloud.get_zone('mickey')
         self.assertIsNotNone(r)
-        self.assertDictEqual(domain1, r)
+        self.assertDictEqual(zone1, r)
 
-    @mock.patch.object(shade.OpenStackCloud, 'list_records')
+    @mock.patch.object(shade.OpenStackCloud, '_list_records')
     def test_get_record(self, mock_search):
         record1 = dict(id='123', name='mickey', domain_id='mickey.domain')
         mock_search.return_value = [record1]
-        r = self.cloud.get_record('mickey.domain', 'mickey')
+        r = self.cloud._get_record('mickey.domain', 'mickey')
         self.assertIsNotNone(r)
         self.assertDictEqual(record1, r)
+
+    @mock.patch.object(shade._tasks.ServerList, 'main')
+    def test_list_servers(self, mock_serverlist):
+        '''This test verifies that calling list_servers results in a call
+        to the ServerList task.'''
+        mock_serverlist.return_value = [
+            munch.Munch({'name': 'testserver',
+                         'id': '1'})
+        ]
+
+        r = self.cloud.list_servers()
+        self.assertEquals(1, len(r))
+        self.assertEquals('testserver', r[0]['name'])
+
+    @mock.patch.object(shade._tasks.ServerList, 'main')
+    @mock.patch('shade.meta.get_hostvars_from_server')
+    def test_list_servers_detailed(self,
+                                   mock_get_hostvars_from_server,
+                                   mock_serverlist):
+        '''This test verifies that when list_servers is called with
+        `detailed=True` that it calls `get_hostvars_from_server` for each
+        server in the list.'''
+        mock_serverlist.return_value = ['server1', 'server2']
+        mock_get_hostvars_from_server.side_effect = [
+            {'name': 'server1', 'id': '1'},
+            {'name': 'server2', 'id': '2'},
+        ]
+
+        r = self.cloud.list_servers(detailed=True)
+
+        self.assertEquals(2, len(r))
+        self.assertEquals(len(r), mock_get_hostvars_from_server.call_count)
+        self.assertEquals('server1', r[0]['name'])
+        self.assertEquals('server2', r[1]['name'])
